@@ -20,7 +20,7 @@ pub mod types;
 pub mod webhook;
 
 pub use self::{
-    api::{Api, ApiError, Config, DownloadFileError, ExecuteError, ParseProxyError},
+    api::{Api, ApiError, DownloadFileError, ExecuteError},
     handler::{SyncedUpdateHandler, UpdateHandler},
 };
 
